==> zio-aws-elasticinference_2.12-5.17.104.9-sources.jar: zio/aws/elasticinference/model/MemoryInfo.scala <==
package zio.aws.elasticinference.model
import zio.aws.elasticinference.model.primitives.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class MemoryInfo(sizeInMiB: Option[Integer] = None) {
  def buildAwsValue()
      : software.amazon.awssdk.services.elasticinference.model.MemoryInfo = {
    import MemoryInfo.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.elasticinference.model.MemoryInfo
      .builder()
      .optionallyWith(
        sizeInMiB.map(value => Integer.unwrap(value): java.lang.Integer)
      )(_.sizeInMiB)
      .build()
  }
  def asReadOnly: zio.aws.elasticinference.model.MemoryInfo.ReadOnly =
    zio.aws.elasticinference.model.MemoryInfo.wrap(buildAwsValue())
}
object MemoryInfo {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.elasticinference.model.MemoryInfo
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.elasticinference.model.MemoryInfo =
      zio.aws.elasticinference.model.MemoryInfo(sizeInMiB.map(value => value))
    def sizeInMiB: Option[Integer]
    def getSizeInMiB: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("sizeInMiB", sizeInMiB)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.elasticinference.model.MemoryInfo
  ) extends zio.aws.elasticinference.model.MemoryInfo.ReadOnly {
    override val sizeInMiB: Option[Integer] = scala
      .Option(impl.sizeInMiB())
      .map(value => zio.aws.elasticinference.model.primitives.Integer(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.elasticinference.model.MemoryInfo
  ): zio.aws.elasticinference.model.MemoryInfo.ReadOnly = new Wrapper(impl)
}

==> zio-aws-elasticinference_2.12-5.17.151.1-sources.jar: zio/aws/elasticinference/model/MemoryInfo.scala <==
package zio.aws.elasticinference.model
import zio.aws.elasticinference.model.primitives.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class MemoryInfo(sizeInMiB: Option[Integer] = None) {
  def buildAwsValue()
      : software.amazon.awssdk.services.elasticinference.model.MemoryInfo = {
    import MemoryInfo.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.elasticinference.model.MemoryInfo
      .builder()
      .optionallyWith(sizeInMiB.map(value => value: java.lang.Integer))(
        _.sizeInMiB
      )
      .build()
  }
  def asReadOnly: zio.aws.elasticinference.model.MemoryInfo.ReadOnly =
    zio.aws.elasticinference.model.MemoryInfo.wrap(buildAwsValue())
}
object MemoryInfo {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.elasticinference.model.MemoryInfo
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.elasticinference.model.MemoryInfo =
      zio.aws.elasticinference.model.MemoryInfo(sizeInMiB.map(value => value))
    def sizeInMiB: Option[Integer]
    def getSizeInMiB: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("sizeInMiB", sizeInMiB)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.elasticinference.model.MemoryInfo
  ) extends zio.aws.elasticinference.model.MemoryInfo.ReadOnly {
    override val sizeInMiB: Option[Integer] =
      scala.Option(impl.sizeInMiB()).map(value => value: Integer)
  }
  def wrap(
      impl: software.amazon.awssdk.services.elasticinference.model.MemoryInfo
  ): zio.aws.elasticinference.model.MemoryInfo.ReadOnly = new Wrapper(impl)
}
